@@ -82,7 +82,7 @@ def setup(settings_path=None, **settings_patches):
 
     # Install packages for building uwsgi
     print section_title('Install system packages')
-    local('yum install -y python-devel sqlite-devel libxml2-devel pcre-devel zeromq-devel'
+    local('yum install -y python-virtualenv python-devel sqlite-devel libxml2-devel pcre-devel zeromq-devel'
           ' libcap-devel libuuid-devel libev-devel python-greenlet-devel httpd-devel')
 
     # Install Uwsgi
